@@ -47,9 +47,10 @@ def imports() -> str:
     return "\n".join(lines)
 
 
-async def build_enums(client: edgedb.AsyncIOClient) -> str:
+async def build_enums(client: edgedb.AsyncIOClient, include_strawberry: bool) -> str:
     scalar_types = await introspect_scalars(client)
     enum_strs: T.List[str] = []
+    enum_names: T.List[str] = []
     for scalar in scalar_types:
         if not scalar.enum_values:
             continue
@@ -57,6 +58,16 @@ async def build_enums(client: edgedb.AsyncIOClient) -> str:
         enum_value_str = "\n".join(enum_value_strs)
         s = f"class {scalar.node_name}(str, Enum):\n{indent_lines(enum_value_str)}"
         enum_strs.append(s)
+        enum_names.append(scalar.node_name)
+    if include_strawberry:
+        straw_enums_str = "\n".join(
+            [f"{enum_name} = strawberry.enum({enum_name})" for enum_name in enum_names]
+        )
+        straw_lines = [
+            "import strawberry",
+            f"class Strawberry:\n{indent_lines(straw_enums_str)}",
+        ]
+        enum_strs.extend(straw_lines)
     return "\n".join(enum_strs)
 
 
@@ -441,7 +452,9 @@ def get_nodes_to_hydrate(db_config: DBConfig) -> T.Set[str]:
     return node_names
 
 
-async def build_from_config(db_config_d: dict, hydrate: bool = False) -> str:
+async def build_from_config(
+    db_config_d: dict, include_strawberry: bool, hydrate: bool = False
+) -> str:
     db_config = DBConfig.parse_obj(db_config_d)
     client = edgedb.create_async_client(
         tls_security=db_config.tls_security,
@@ -452,7 +465,7 @@ async def build_from_config(db_config_d: dict, hydrate: bool = False) -> str:
     imports_str = imports()
     client_str = build_client(db_config)
     hydrate_imports = "" if not hydrate else build_hydrate_imports(db_config)
-    enums_str = await build_enums(client)
+    enums_str = await build_enums(client, include_strawberry=include_strawberry)
     nodes_and_resolvers_str = await build_nodes_and_resolvers(
         client,
         nodes_to_hydrate=set() if not hydrate else get_nodes_to_hydrate(db_config),
@@ -465,11 +478,22 @@ async def build_from_config(db_config_d: dict, hydrate: bool = False) -> str:
     return s
 
 
-async def generate(config_path: Path, output_path: Path) -> None:
+async def generate(
+    config_path: Path, output_path: Path, include_strawberry: bool = False
+) -> None:
     validate_output_path(output_path)
     for db_name, db_config_d in json.loads(open(config_path).read()).items():
-        s = await build_from_config(db_config_d=db_config_d)
+        hydrate = db_config_d.get("hydrate", False)
+        # if hydrate is True, will include in second go
+        s = await build_from_config(
+            db_config_d=db_config_d,
+            include_strawberry=include_strawberry and not hydrate,
+        )
         open(output_path / f"{db_name}.py", "w").write(s)
-        if db_config_d.get("hydrate", False):
-            s = await build_from_config(db_config_d=db_config_d, hydrate=True)
+        if hydrate:
+            s = await build_from_config(
+                db_config_d=db_config_d,
+                hydrate=True,
+                include_strawberry=include_strawberry,
+            )
             open(output_path / f"{db_name}_hydrated.py", "w").write(s)
